/*
 * Copyright (C) 2006 Apple Computer, Inc.  All rights reserved.
 * Copyright (C) 2006 Michael Emmel mike.emmel@gmail.com
 * Copyright (C) 2006 George Staikos <staikos@kde.org>
 * Copyright (C) 2006 Dirk Mueller <mueller@kde.org>
 * Copyright (C) 2006 Nikolas Zimmermann <zimmermann@kde.org>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#include <stdio.h>
#include <stdlib.h>
#include "Node.h"
#include "Frame.h"
#include "Font.h"
#include "IntPoint.h"
#include "Widget.h"
#include "GraphicsContext.h"
#include "Cursor.h"
#include "loader.h"
#include "FrameView.h"
#include "KURL.h"
#include "ScrollBar.h"
#include "PlatformScrollBar.h"
#include "CachedResource.h"
#include "ScrollBar.h"
#include "Path.h"
#include "PlatformMouseEvent.h"
#include "CookieJar.h"
#include "Screen.h"
#include "History.h"
#include "Language.h"
#include "LocalizedStrings.h"
#include "PlugInInfoStore.h"
#include "RenderTheme.h"
#include "TextBoundaries.h"
#include "AXObjectCache.h"
#include "IconLoader.h"
#include "NotImplemented.h"

using namespace WebCore;


FloatRect Font::selectionRectForComplexText(const TextRun&, const TextStyle&, const IntPoint&, int, int, int) const { return FloatRect(); notImplemented(); }
int Font::offsetForPositionForComplexText(const TextRun&, const TextStyle&, int, bool) const { notImplemented(); return 0; }


void WebCore::refreshPlugins(bool) { notImplemented(); }

namespace WebCore
{
bool historyContains(DeprecatedString const&) { return false; }
};

// LocalizedStrings
String WebCore::submitButtonDefaultLabel() { return "Submit"; }
String WebCore::inputElementAltText() { return String(); }
String WebCore::resetButtonDefaultLabel() { return "Reset"; }
String WebCore::defaultLanguage() { return "en"; }
String WebCore::searchableIndexIntroduction() { return "Searchable Index"; }
String WebCore::fileButtonChooseFileLabel() { return "Choose File"; }
String WebCore::fileButtonNoFileSelectedLabel() { return "No file selected"; }
String WebCore::contextMenuItemTagOpenLinkInNewWindow() { return String( "Open in new tab" ); }
String WebCore::contextMenuItemTagDownloadLinkToDisk() { return String( "Download link to disk" ); }
String WebCore::contextMenuItemTagCopyLinkToClipboard() { return String( "Copy link to clipboard" ); }
String WebCore::contextMenuItemTagOpenImageInNewWindow() { return String( "Open image in new window" ); }
String WebCore::contextMenuItemTagDownloadImageToDisk() { return String( "Download image to disk" ); }
String WebCore::contextMenuItemTagCopyImageToClipboard() { return String( "Copy image to clipboard" ); }
String WebCore::contextMenuItemTagOpenFrameInNewWindow() { return String( "Open frame in new window" ); }
String WebCore::contextMenuItemTagCopy() { return String( "Copy" ); }
String WebCore::contextMenuItemTagGoBack() { return String( "Go back" ); }
String WebCore::contextMenuItemTagGoForward() { return String( "Go forward" ); }
String WebCore::contextMenuItemTagStop() { return String( "Stop" ); }
String WebCore::contextMenuItemTagReload() { return String( "Reload" ); }
String WebCore::contextMenuItemTagCut() { return String( "Cut" ); }
String WebCore::contextMenuItemTagPaste() { return String( "Paste" ); }
String WebCore::contextMenuItemTagNoGuessesFound() { return String( "No guesses found" ); }
String WebCore::contextMenuItemTagIgnoreSpelling() { return String( "Ignore spelling" ); }
String WebCore::contextMenuItemTagLearnSpelling() { return String( "Learn spelling" ); }
String WebCore::contextMenuItemTagSearchWeb() { return String( "Search web" ); }
String WebCore::contextMenuItemTagLookUpInDictionary() { return String( "Lookup in dictionary" ); }
String WebCore::contextMenuItemTagOpenLink() { return String( "Open link" ); }
String WebCore::contextMenuItemTagIgnoreGrammar() { return String( "Ignore grammar" ); }
String WebCore::contextMenuItemTagSpellingMenu() { return String( "Spelling menu" ); }
String WebCore::contextMenuItemTagShowSpellingPanel(bool show) { return String( "Show spelling panel" ); }
String WebCore::contextMenuItemTagCheckSpelling() { return String( "Check spelling" ); }
String WebCore::contextMenuItemTagCheckSpellingWhileTyping() { return String( "Check spelling while typing" ); }
String WebCore::contextMenuItemTagCheckGrammarWithSpelling() { return String( "Check for grammar with spelling" ); }
String WebCore::contextMenuItemTagFontMenu() { return String( "Font menu" ); }
String WebCore::contextMenuItemTagBold() { return String( "Bold" ); }
String WebCore::contextMenuItemTagItalic() { return String( "Italic" ); }
String WebCore::contextMenuItemTagUnderline() { return String( "Underline" ); }
String WebCore::contextMenuItemTagOutline() { return String( "Outline" ); }
String WebCore::contextMenuItemTagWritingDirectionMenu() { return String( "Writing direction menu" ); }
String WebCore::contextMenuItemTagDefaultDirection() { return String( "Default direction" ); }
String WebCore::contextMenuItemTagLeftToRight() { return String( "Left to right" ); }
String WebCore::contextMenuItemTagRightToLeft() { return String( "Right to left" ); }
String WebCore::contextMenuItemTagInspectElement() { return String( "Inspect" ); }
String WebCore::searchMenuNoRecentSearchesText() { return String( "No recent text searches" ); }
String WebCore::searchMenuRecentSearchesText() { return String( "Recent text searches" ); }
String WebCore::searchMenuClearRecentSearchesText() { return String( "Clear recent text searches" ); }
String WebCore::AXWebAreaText() { return String(); }
String WebCore::AXLinkText() { return String(); }
String WebCore::AXListMarkerText() { return String(); }
String WebCore::AXImageMapText() { return String(); }
String WebCore::AXHeadingText() { return String(); }

void Frame::setNeedsReapplyStyles() { notImplemented(); }

void FrameView::updateBorder() { notImplemented(); }

bool AXObjectCache::gAccessibilityEnabled = false;

Vector<char> loadResourceIntoArray(const char*) { notImplemented(); return Vector<char>(); }

PluginInfo* PlugInInfoStore::createPluginInfoForPluginAtIndex(unsigned) { notImplemented(); return 0; }
unsigned PlugInInfoStore::pluginCount() const { notImplemented(); return 0; }
bool WebCore::PlugInInfoStore::supportsMIMEType(const WebCore::String&) { return false; }

namespace WebCore {
    
Vector<String> supportedKeySizes() { notImplemented(); return Vector<String>(); }
String signedPublicKeyAndChallengeString(unsigned keySizeIndex, const String &challengeString, const KURL &url) { return String(); }
    
float userIdleTime() { notImplemented(); return 0.0; }
    
}

// vim: ts=4 sw=4 et

























